#if !defined(AFX_CLIENTSOCKET_H__557220A1_EB79_11D4_8F73_00105A04B049__INCLUDED_)
#define AFX_CLIENTSOCKET_H__557220A1_EB79_11D4_8F73_00105A04B049__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// ClientSocket.h : header file
//

#include <afxsock.h>
#include "strings.h"
#include "..\INCLUDE\strings.h"	// Added by ClassView
#include "..\INCLUDE\linkedlist.h"

/////////////////////////////////////////////////////////////////////////////
// CClientSocket command target

class CClientSocket : public CSocket
{
// Attributes
public:

// Operations
public:
	CClientSocket();
	virtual ~CClientSocket();

// Overrides
public:
	virtual void OnReceive( int nErrorCode );
	virtual void OnConnect( int nErrorCode );
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CClientSocket)
	//}}AFX_VIRTUAL

	// Generated message map functions
	//{{AFX_MSG(CClientSocket)
		// NOTE - the ClassWizard will add and remove member functions here.
	//}}AFX_MSG

// Implementation
protected:

public:
	void unlock();
	BOOL set_locked();
	int fill_read_buffer(char *input_buf);

	BOOL valid_input;
	Strings write_buffer;
	LinkedList<Strings> read_buffer;
    Strings partial_line;

private:
	BOOL locked;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_CLIENTSOCKET_H__557220A1_EB79_11D4_8F73_00105A04B049__INCLUDED_)

